# Customization of the components

## What is Customization?

When we talk about customization, we are talking about the ability to change the behavior of the components. This can be done by changing the default behavior of the components or by adding new behavior to the components. This can be done by creating a new component or by extending the existing component.

## How to Customize Components?

Customization of the components can be done by creating a new component or by extending the existing component. The new component can be created by subclassing the `BaseElement` class and adding the new behavior to the component. The existing component can be extended by subclassing the existing component and adding the new behavior to the component.

We will see how to create a new component and how to extend the existing component in the following sections.

- [HTML Customization](./customized-html.md)
- [CSS Customization](./customized-css.md)
- [Javascript Customization](./customized-js.md)
